@@ -1,11 +1,10 @@
 """
 Provides XML rendering support.
 """
-from __future__ import unicode_literals
+from io import StringIO
 
-from django.utils import six
+from django.utils.encoding import force_str
 from django.utils.xmlutils import SimplerXMLGenerator
-from rest_framework.compat import StringIO, smart_text
 from rest_framework.renderers import BaseRenderer
 
 
@@ -14,38 +13,40 @@ class XMLRenderer(BaseRenderer):
     Renderer which serializes to XML.
     """
 
-    media_type = 'application/xml'
-    format = 'xml'
-    charset = 'utf-8'
+    media_type = "application/xml"
+    format = "xml"
+    charset = "utf-8"
+    item_tag_name = "list-item"
+    root_tag_name = "root"
 
     def render(self, data, accepted_media_type=None, renderer_context=None):
         """
         Renders `data` into serialized XML.
         """
         if data is None:
-            return ''
+            return ""
 
         stream = StringIO()
 
         xml = SimplerXMLGenerator(stream, self.charset)
         xml.startDocument()
-        xml.startElement("root", {})
+        xml.startElement(self.root_tag_name, {})
 
         self._to_xml(xml, data)
 
-        xml.endElement("root")
+        xml.endElement(self.root_tag_name)
         xml.endDocument()
         return stream.getvalue()
 
     def _to_xml(self, xml, data):
         if isinstance(data, (list, tuple)):
             for item in data:
-                xml.startElement("list-item", {})
+                xml.startElement(self.item_tag_name, {})
                 self._to_xml(xml, item)
-                xml.endElement("list-item")
+                xml.endElement(self.item_tag_name)
 
         elif isinstance(data, dict):
-            for key, value in six.iteritems(data):
+            for key, value in data.items():
                 xml.startElement(key, {})
                 self._to_xml(xml, value)
                 xml.endElement(key)
@@ -55,4 +56,4 @@ class XMLRenderer(BaseRenderer):
             pass
 
         else:
-            xml.characters(smart_text(data))
+            xml.characters(force_str(data))
